@@ -53,7 +53,7 @@ class Formatter(text_html.Formatter):
         if not on:
             return self.url(0) # return '</a>'
         html_class = 'badinterwiki' # we use badinterwiki in any case to simplify reverse conversion
-        href = wikiutil.quoteWikinameURL(pagename)
+        href = wikiutil.quoteWikinameURL(pagename) or "/" # FCKeditor behaves strange on empty href
         title = kw.get('title', interwiki)
         return self.url(1, href, title=title, do_escape=1, css=html_class) # interwiki links with pages with umlauts
 
