@@ -20,7 +20,9 @@ class Formatter:
         Page must be assembled after the parsing to get working python code.
     """
 
-    def __init__(self, request, static = [], formatter = None, **kw):
+    defaultDependencies = ["time"]
+    
+    def __init__(self, request, static=[], formatter=None, **kw):
         if formatter:
             self.formatter = formatter
         else:
@@ -40,19 +42,6 @@ class Formatter:
     def assemble_code(self, text):
         """inserts the code into the generated text
         """
-        #text = text.replace('\\', '\\\\')
-        #text = text.replace('"', '\\"')
-        text = text.split('<<<>>>', len(self.code_fragments))
-        source = self.text_cmd_begin + repr(text[0])
-        i = 0
-        for t in text[1:]:
-            source = (source + self.text_cmd_end +
-                      self.code_fragments[i] +
-                      self.text_cmd_begin + repr(text[i+1]))
-            i = i + 1
-        source = source + self.text_cmd_end
-        self.code_fragments = [] # clear code fragments to make
-                                 # this object reusable
         # Automatic invalidation due to moin code changes:
         # we are called from Page.py, so moincode_timestamp is
         # mtime of MoinMoin directory. If we detect, that the
@@ -63,12 +52,28 @@ class Formatter:
         # MoinMoin, so better do a touch if you only modified stuff
         # in a subdirectory.
         waspcode_timestamp = int(time.time())
-        source = """
+        source = ["""
 moincode_timestamp = int(os.path.getmtime(os.path.dirname(__file__)))
-if moincode_timestamp > %d: raise "CacheNeedsUpdate"
-%s
-""" % (waspcode_timestamp, source)
-        return source
+if moincode_timestamp > %d or request.cfg.cfg_mtime > %d:
+    raise "CacheNeedsUpdate"
+""" % (waspcode_timestamp, waspcode_timestamp)]
+
+
+        text = text.split('<<<>>>', len(self.code_fragments))
+        source.extend([self.text_cmd_begin, repr(text[0])])
+        i = 0
+        for t in text[1:]:
+            source.extend([self.text_cmd_end,
+                           self.code_fragments[i],
+                           self.text_cmd_begin,
+                           repr(text[i+1])])
+            i += 1
+        source.append(self.text_cmd_end)
+        source.append(self.__adjust_formatter_state())
+        
+        self.code_fragments = [] # clear code fragments to make
+                                 # this object reusable
+        return "".join(source)
 
     def __getattr__(self, name):
         """ For every thing we have no method/attribute use the formatter
@@ -83,10 +88,11 @@ if moincode_timestamp > %d: raise "CacheNeedsUpdate"
 
     def __is_static(self, dependencies):
         for dep in dependencies:
-            if dep not in  self.static: return False
+            if dep not in self.static:
+                return False
         return True
 
-    def __adjust_languge_state(self):
+    def __adjust_language_state(self):
         """ Add current language state changing code to the cache """
         if self.__lang != self.request.current_lang:
             self.__lang = self.request.current_lang
@@ -94,7 +100,7 @@ if moincode_timestamp > %d: raise "CacheNeedsUpdate"
         return ''
         
     def __adjust_formatter_state(self):
-        result = self.__adjust_languge_state()
+        result = self.__adjust_language_state()
         if self.__in_p != self.formatter.in_p:
             result = "%s%s.in_p = %r\n" % (result, self.__formatter,
                                            self.formatter.in_p)
@@ -105,8 +111,8 @@ if moincode_timestamp > %d: raise "CacheNeedsUpdate"
             self.__in_pre = self.formatter.in_pre        
         return result
     
-    def dynamic_content(self, parser, callback, arg_list = [], arg_dict = {},
-                            returns_content = 1):
+    def dynamic_content(self, parser, callback, arg_list=[], arg_dict={},
+                            returns_content=1):
         adjust = self.__adjust_formatter_state()
         if returns_content:
             return self.__insert_code('%srequest.write(%s.%s(*%r,**%r))' %
@@ -127,29 +133,30 @@ if moincode_timestamp > %d: raise "CacheNeedsUpdate"
             return self.__insert_code('request.write(%s.pagelink(%r, page=page, **%r))' %
                                       (self.__formatter, on, kw))
 
-    def attachment_link(self, on, url='', **kw):
+    def attachment_link(self, url, text, **kw):
         return self.__insert_code(
             'request.write(%s.attachment_link(%r, %r, **%r))' %
-            (self.__formatter, on, url, kw))
+            (self.__formatter, url, text, kw))
+
     def attachment_image(self, url, **kw):
         return self.__insert_code(
             'request.write(%s.attachment_image(%r, **%r))' %
             (self.__formatter, url, kw))
     
-    def attachment_drawing(self, url, **kw):
+    def attachment_drawing(self, url, text, **kw):
         return self.__insert_code(
-            'request.write(%s.attachment_drawing(%r, **%r))' %
-            (self.__formatter, url, kw))
+            'request.write(%s.attachment_drawing(%r, %r, **%r))' %
+            (self.__formatter, url, text, kw))
     
-    def attachment_inlined(self, url, **kw):
+    def attachment_inlined(self, url, text, **kw):
         return self.__insert_code(
-            'request.write(%s.attachment_inlined(%r, **%r))' %
-            (self.__formatter, url, kw))
+            'request.write(%s.attachment_inlined(%r, %r, **%r))' %
+            (self.__formatter, url, text, kw))
 
     def heading(self, on, depth, **kw):        
         if on:
             code = [
-                self.__adjust_languge_state(),
+                self.__adjust_language_state(),
                 'request.write(%s.heading(%r, %r, **%r))' % (self.__formatter,
                                                              on, depth, kw),
                 ]     
@@ -173,19 +180,17 @@ if moincode_timestamp > %d: raise "CacheNeedsUpdate"
                 (self.__adjust_formatter_state(),
                  self.__formatter, name, args))
             
-    def processor(self, processor_name, lines, is_parser = 0):
+    def processor(self, processor_name, lines, is_parser=0):
         """ processor_name MUST be valid!
         prints out the result insted of returning it!
         """
-        if not is_parser:
-            Dependencies = wikiutil.importPlugin(self.request.cfg, "processor",
-                                                 processor_name, "Dependencies")
-        else:
-            Dependencies = wikiutil.importPlugin(self.request.cfg, "parser",
-                                                 processor_name, "Dependencies")
-            
-        if Dependencies == None:
-            Dependencies = ["time"]
+        type = ["processor", "parser"][is_parser]
+        try:
+            Dependencies = wikiutil.importPlugin(self.request.cfg, type,
+                                                 processor_name,
+                                                 "Dependencies")
+        except wikiutil.PluginAttributeError:
+            Dependencies = self.defaultDependencies
         if self.__is_static(Dependencies):
             return self.formatter.processor(processor_name, lines, is_parser)
         else:
