@@ -275,10 +275,19 @@ def getText(str, request, lang, formatted=True):
                 if dicts.has_dict(dictpagename):
                     userdict = dicts.dict(dictpagename)
                     trans = userdict[str]
+                else:
+                    raise KeyError
+            else:
+                raise KeyError
         except KeyError:
             # do not simply return trans with str, but recursively call
-            # to get english translation, maybe formatted
+            # to get english translation, maybe formatted.
+            # if we don't find an english "translation", we just format it
+            # on the fly (this is needed for cfg.editor_quickhelp).
             if lang != 'en':
                 trans = getText(str, request, 'en', formatted)
+            elif formatted:
+                trans = formatMarkup(request, str)
+
     return trans
 
