@@ -130,8 +130,8 @@ def normalizeName(name):
     @return: user name that can be used in acl lines
     """
     name = name.replace('_', ' ') # we treat _ as a blank
-    username_allowedchars = "'@." # ' for names like O'Brian or email addresses.
-                                  # "," and ":" must not be allowed (ACL delimiters).
+    username_allowedchars = "'@.-" # ' for names like O'Brian or email addresses.
+                                   # "," and ":" must not be allowed (ACL delimiters).
     # Strip non alpha numeric characters (except username_allowedchars), keep white space
     name = ''.join([c for c in name if c.isalnum() or c.isspace() or c in username_allowedchars])
 
@@ -960,7 +960,7 @@ Login Name: %s
 
 Login Password: %s
 
-Login URL: %s/%s
+Login URL: %s/%s?action=login
 """, formatted=False) % (
                         self.name, self.enc_password, self._request.getBaseURL(), getSysPage(self._request, 'UserPreferences').page_name)
 
